@@ -4,7 +4,7 @@ from gitty import GittyCommand, Color
 class GittyHelp(GittyCommand):
     _title = 'help'
     _name = 'what am i even doing here?'
-    _bindings = ['h', 'help']
+    _bindings = ['help', 'h']
 
     def do_it(self, context):
         print('available commands on branch "{}" are:'.format(Color.white_lt(context['current_branch'])))
